| maxEff-package | R Documentation |
Methods of selecting one from many numeric predictors for a regression model, to ensure that the additional predictor has the maximum effect size.
Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.