statusPartition: Stratified Partition

View source: R/statusPartition.R

statusPartitionR Documentation

Stratified Partition

Description

A variation of createDataPartition, to split Surv y by survival status instead of the percentiles survival time.

Usage

statusPartition(y, times, p = 0.8, ...)

Arguments

y

response y, a Surv object

times

positive integer scalar n, number of replicates of partitions. Default 1L.

p

double scalar between 0 and 1, percentage p of training subjects, default .8

...

additional parameters, currently not in use

Details

See vignette('intro', package = 'maxEff').

Value

The function statusPartition() returns a length-n listof integer vectors. In each integer vector indicates the training subjects.

Note

The function caTools::sample.split is not what we need.

References

https://tingtingzhan.quarto.pub/groupedhyperframe/nonS3/statusPartition.html


maxEff documentation built on March 3, 2026, 1:07 a.m.